@@ -22,14 +22,17 @@ from lino.api import dd, rt, _
 from lino.core.gfks import gfk2lookup
 from lino.core.utils import model_class_path
 from lino import mixins
+from lino.mixins.sequenced import Sequenced
 from lino.modlib.gfks.mixins import Controllable
 from lino.modlib.users.mixins import UserAuthored, My
 from lino.modlib.office.roles import OfficeUser, OfficeStaff, OfficeOperator
 from lino.mixins import Hierarchical
-from lino.mixins.sequenced import Sequenced
 from lino.utils.mldbc.mixins import BabelDesignated
+# from lino.modlib.uploads.mixins import UploadBase, safe_filename, FileUsable, GalleryViewable
 from lino.modlib.uploads.mixins import UploadBase, safe_filename, GalleryViewable
 from lino.core import constants
+
+
 # class ShowGallery(dd.ShowTable):
 #     # select_rows = False
 #     pass
@@ -56,6 +59,8 @@ class File(UploadBase, UserAuthored):
         verbose_name = _("Media file")
         verbose_name_plural = _("Media files")
 
+    memo_command = 'image'
+
     # show_gallery = ShowGallery()
 
     album = dd.ForeignKey("albums.Album", blank=True, null=True)
@@ -149,72 +154,73 @@ class File(UploadBase, UserAuthored):
 dd.update_field(File, 'user', verbose_name=_("Uploaded by"))
 
 
-class UploadNewFileField(dd.VirtualField):
+# class UploadNewFileField(dd.VirtualField):
+#
+#     """An editable virtual field needed for uploading new files.
+#     """
+#     editable = True
+#
+#     def __init__(self, upload_to_model, label):
+#         self.upload_to_model = upload_to_model
+#         return_type = models.FileField(label)
+#         dd.VirtualField.__init__(self, return_type, None)
+#
+#     def set_value_in_object(self, request, obj, value):
+#         if value is not None and value != "":
+#             target = self.upload_to_model(file=value)
+#             target.full_clean()
+#             target.save()
+#             obj.file = target
+#
+#     def value_from_object(self, obj, ar):
+#         return None
 
-    """An editable virtual field needed for uploading new files.
-    """
-    editable = True
-
-    def __init__(self, upload_to_model, label):
-        self.upload_to_model = upload_to_model
-        return_type = models.FileField(label)
-        dd.VirtualField.__init__(self, return_type, None)
-
-    def set_value_in_object(self, request, obj, value):
-        if value is not None and value != "":
-            target = self.upload_to_model(file=value)
-            target.full_clean()
-            target.save()
-            obj.file = target
-
-    def value_from_object(self, obj, ar):
-        return None
-
-class FileUsage(Sequenced, Controllable, GalleryViewable):
-    class Meta(object):
-        abstract = dd.is_abstract_model(__name__, 'FileUsage')
-        verbose_name = _("Usage")
-        verbose_name_plural = _("File usages")
-
-    file = dd.ForeignKey("albums.File")
-    upload_new_file = UploadNewFileField(File, _("Upload new file"))
-
-    primary_image = models.BooleanField(default=False, verbose_name=_("Primary Image"))
-
-    delete_old_primary_image_field = dd.VirtualBooleanField('delete_old_primary_image', _("Delete Old Primary Image"))
-    delete_old_primary_image = False
-
-    def handle_uploaded_files(self, request, file=None):
-        if not file and not 'upload_new_file' in request.FILES:
-            dd.logger.debug("No new file has been submitted.")
-            return
-        file = file or request.FILES['upload_new_file']
-        if file.content_type.split('/')[0] != 'image':
-            raise ValidationError(
-                _("Invalid Type: This is not an image! Please choose an image to upload."))
-
-        self.upload_new_file = file
-
-    def get_gallery_item(self, ar):
-        d = self.file.get_gallery_item(ar)
-        d.update(id=self.pk)
-        return d
-
-    def clean(self):
-        super().clean()
-        if self.primary_image and self.owner is not None:
-            qs = self.__class__.objects.filter(owner_type=self.owner_type,
-                owner_id=self.owner_id, primary_image=True).exclude(file=self.file)
-            assert qs.count() <= 1
-            if qs.count():
-                obj = qs[0]
-                if self.delete_old_primary_image:
-                    file = obj.file
-                    obj.delete()
-                    file.delete()
-                else:
-                    obj.primary_image = False
-                    obj.save()
+# class FileUsage(FileUsable, GalleryViewable):
+# class FileUsage(Sequenced, Controllable, GalleryViewable):
+#     class Meta(object):
+#         abstract = dd.is_abstract_model(__name__, 'FileUsage')
+#         verbose_name = _("Usage")
+#         verbose_name_plural = _("File usages")
+#
+#     file = dd.ForeignKey("albums.File")
+#     upload_new_file = UploadNewFileField(File, _("Upload new file"))
+#
+#     primary_image = models.BooleanField(default=False, verbose_name=_("Primary Image"))
+#
+#     delete_old_primary_image_field = dd.VirtualBooleanField('delete_old_primary_image', _("Delete Old Primary Image"))
+#     delete_old_primary_image = False
+#
+#     def handle_uploaded_files(self, request, file=None):
+#         if not file and not 'upload_new_file' in request.FILES:
+#             dd.logger.debug("No new file has been submitted.")
+#             return
+#         file = file or request.FILES['upload_new_file']
+#         if file.content_type.split('/')[0] != 'image':
+#             raise ValidationError(
+#                 _("Invalid Type: This is not an image! Please choose an image to upload."))
+#
+#         self.upload_new_file = file
+#
+#     def get_gallery_item(self, ar):
+#         d = self.file.get_gallery_item(ar)
+#         d.update(id=self.pk)
+#         return d
+#
+#     def clean(self):
+#         super().clean()
+#         if self.primary_image and self.owner is not None:
+#             qs = self.__class__.objects.filter(owner_type=self.owner_type,
+#                 owner_id=self.owner_id, primary_image=True).exclude(file=self.file)
+#             assert qs.count() <= 1
+#             if qs.count():
+#                 obj = qs[0]
+#                 if self.delete_old_primary_image:
+#                     file = obj.file
+#                     obj.delete()
+#                     file.delete()
+#                 else:
+#                     obj.primary_image = False
+#                     obj.save()
 
 
 class Files(dd.Table):
@@ -294,92 +300,93 @@ class AlbumsByAlbum(Albums):
     master_key = "parent"
 
 
-class FileUsages(dd.Table):
-    model = 'albums.FileUsage'
-    required_roles = dd.login_required((OfficeUser, OfficeOperator))
-
-    detail_layout = """
-    file id
-    file__file_size
-    file__thumbnail
-    owner seqno primary_image
-    """
-
-    insert_layout = """
-    file
-    upload_new_file
-    seqno primary_image delete_old_primary_image_field
-    """
-
-    @classmethod
-    def get_choices_text(cls, obj, request, field):
-        if str(field) == 'albums.FileUsage.file':
-            return str(obj) + "&nbsp;<span style=\"float: right;\">" + obj.thumbnail + "</span>"
-        return str(obj)
+# class FileUsages(dd.Table):
+#     model = 'albums.FileUsage'
+#     required_roles = dd.login_required((OfficeUser, OfficeOperator))
+#
+#     detail_layout = """
+#     file id
+#     file__file_size
+#     file__thumbnail
+#     owner seqno primary_image
+#     """
+#
+#     insert_layout = """
+#     file
+#     upload_new_file
+#     seqno primary_image delete_old_primary_image_field
+#     """
+#
+#     @classmethod
+#     def get_choices_text(cls, obj, request, field):
+#         if str(field) == 'albums.FileUsage.file':
+#             return str(obj) + "&nbsp;<span style=\"float: right;\">" + obj.thumbnail + "</span>"
+#         return str(obj)
+#
+#
+#
+# class UsagesByController(FileUsages):
+#     label = _("Media files")
+#     master_key = 'owner'
+#     column_names = "seqno file file__thumbnail *"
+#     display_mode = ((None, constants.DISPLAY_MODE_GALLERY), )
+#     # summary_sep = lambda : ", "
 
 
-
-class UsagesByController(FileUsages):
-    label = _("Media files")
-    master_key = 'owner'
-    column_names = "seqno file file__thumbnail *"
-    display_mode = ((None, constants.DISPLAY_MODE_GALLERY), )
-    # summary_sep = lambda : ", "
-
-@dd.receiver(dd.post_startup)
-def setup_memo_commands(sender=None, **kwargs):
-    # See :doc:`/specs/memo`
-
-    if not sender.is_installed('memo'):
-        return
-
-    mp = sender.plugins.memo.parser
-
-    def manage_file_usage(ar, usages):
-        if ar is None or len(ar.selected_rows) != 1: return
-
-        usages = set(usages)
-        owner = ar.selected_rows[0]
-        FileUsage = rt.models.albums.FileUsage
-        lookup = gfk2lookup(FileUsage.owner, owner)
-        qs = set(FileUsage.objects.filter(**lookup))
-        for obj in qs:
-            if obj.file not in usages:
-                qs.remove(obj)
-                obj.delete()
-        qs = {obj.file for obj in qs}
-        for file in usages.difference(qs):
-            fu = FileUsage(file=file, **lookup)
-            fu.full_clean()
-            fu.save()
-
-    def render_img_thumbnail(ar, s, cmdname, usages):
-        args = s.split(None, 1)
-        if len(args) == 1:
-            pk = s
-            caption = None
-        else:
-            pk = args[0]
-            caption = args[1]
-
-        file = rt.models.albums.File.objects.get(pk=pk)
-
-        if usages.get(cmdname, None) is None:
-            usages[cmdname] = [file]
-        else:
-            usages[cmdname].append(file)
-
-        thumbnail = file.thumbnail_large
-
-        if file.description is not None and caption is None:
-            caption = file.description
-
-        elem = (f'<figure class="lino-memo-image">{thumbnail}<figcaption' +
-            ' style="text-align: center;">{caption}</figcaption></figure>')
-
-        return elem
-
-    mp.register_django_model('image', rt.models.albums.File,
-        cmd=render_img_thumbnail,
-        manage_usage=manage_file_usage,
-        title=lambda obj: obj.description)
+# @dd.receiver(dd.post_startup)
+# def setup_memo_commands(sender=None, **kwargs):
+#     # See :doc:`/specs/memo`
+#
+#     if not sender.is_installed('memo'):
+#         return
+#
+#     mp = sender.plugins.memo.parser
+#
+#     # def manage_file_usage(ar, usages):
+#     #     if ar is None or len(ar.selected_rows) != 1: return
+#     #
+#     #     usages = set(usages)
+#     #     owner = ar.selected_rows[0]
+#     #     FileUsage = rt.models.albums.FileUsage
+#     #     lookup = gfk2lookup(FileUsage.owner, owner)
+#     #     qs = set(FileUsage.objects.filter(**lookup))
+#     #     for obj in qs:
+#     #         if obj.file not in usages:
+#     #             qs.remove(obj)
+#     #             obj.delete()
+#     #     qs = {obj.file for obj in qs}
+#     #     for file in usages.difference(qs):
+#     #         fu = FileUsage(file=file, **lookup)
+#     #         fu.full_clean()
+#     #         fu.save()
+#
+#     def render_img_thumbnail(ar, s, cmdname, usages):
+#         args = s.split(None, 1)
+#         if len(args) == 1:
+#             pk = s
+#             caption = None
+#         else:
+#             pk = args[0]
+#             caption = args[1]
+#
+#         file = rt.models.albums.File.objects.get(pk=pk)
+#
+#         if usages.get(cmdname, None) is None:
+#             usages[cmdname] = [file]
+#         else:
+#             usages[cmdname].append(file)
+#
+#         thumbnail = file.thumbnail_large
+#
+#         if file.description is not None and caption is None:
+#             caption = file.description
+#
+#         elem = (f'<figure class="lino-memo-image">{thumbnail}<figcaption' +
+#             ' style="text-align: center;">{caption}</figcaption></figure>')
+#
+#         return elem
+#
+#     mp.register_django_model('image', rt.models.albums.File)
+#         # cmd=render_img_thumbnail,
+#         # manage_usage=manage_file_usage,
+#         # title=lambda obj: obj.description)
