@@ -1,10 +1,7 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2018-2019 Rumma 6 Ko Ltd
+# Copyright 2018-2022 Rumma 6 Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-from __future__ import division
-
-from os.path import join
 import time
 import json
 # from django import http
@@ -37,7 +34,7 @@ def read_card_data_from_file(fn):
 def load_card_data(uuid):
     # raise Exception("20180412 {}".format(uuid))
     if dd.plugins.beid.simulate_eidreader_path is None:
-        fn = dd.plugins.beid.data_cache_dir.child(uuid)
+        fn = dd.plugins.beid.data_cache_dir / uuid
     else:
         fn = dd.plugins.beid.SIMULATION_FILES.pop()
     timeout = dd.plugins.beid.eidreader_timeout
@@ -73,11 +70,11 @@ class EidStore(View):
         # if not card_data:
         #     raise Exception("No card_data found in {}".format(
         #         request.POST))
-        fn = dd.plugins.beid.data_cache_dir.child(uuid)
+        fn = dd.plugins.beid.data_cache_dir / uuid
         # pth = dd.plugins.beid.data_cache_dir
         # pth = join(pth, uuid)
         try:
-            fp = open(fn, 'w')
+            fp = fn.open('w')
             fp.write(card_data)
             # json.dump(card_data, fp)
             fp.close()
