@@ -1,5 +1,5 @@
 # Copyright 2008-2019 Rumma & Ko Ltd
-"""Belgian VAT declarations.  See :doc:`/specs/bevat`.
+"""Belgian VAT declarations.  See :doc:`/plugins/bevat`.
 
 """
 
@@ -15,5 +15,3 @@ class Plugin(ad.Plugin):
         m = m.add_menu("vat", site.plugins.vat.verbose_name)
         m.add_action('bevat.Declarations')
         m.add_action('bevat.DeclarationFields')
-
-
