@@ -40,6 +40,7 @@ from lino.modlib.notify.mixins import ChangeNotifier
 from lino_xl.lib.xl.choicelists import Priorities
 
 from .choicelists import Recurrencies, Weekdays, AccessClasses, EntryStates, DisplayColors
+# from .choicelists import PositioningTypes
 from .utils import day_and_month, day_and_weekday
 from .actions import UpdateAllGuests
 # from .roles import CalendarOperator
@@ -538,6 +539,35 @@ class EventGenerator(dd.Model):
     #         lbl = "{0}{1}".format(lbl, evt.state.button_text)
     #     yield ar.obj2html(evt, lbl)
 
+#
+# class RecurByRule(dd.Model):
+#     class Meta:
+#         abstract = dd.is_abstract_model(__name__, 'RecurByRule')
+#         app_label = 'cal'
+#         verbose_name = _("Recur by rule")
+#         verbose_name_plural = _("Recur by rules")
+#
+#     name = RecurBy.field(_("Recur by"), default='byday')
+#     positions = models.CharField(_("Positions"), blank=True, max_length=500)
+#
+#     monday = models.BooleanField(Weekdays.monday.text, default=False)
+#     tuesday = models.BooleanField(Weekdays.tuesday.text, default=False)
+#     wednesday = models.BooleanField(Weekdays.wednesday.text, default=False)
+#     thursday = models.BooleanField(Weekdays.thursday.text, default=False)
+#     friday = models.BooleanField(Weekdays.friday.text, default=False)
+#     saturday = models.BooleanField(Weekdays.saturday.text, default=False)
+#     sunday = models.BooleanField(Weekdays.sunday.text, default=False)
+#
+#
+# class EventRecurBy(dd.Model):
+#     class Meta:
+#         abstract = dd.is_abstract_model(__name__, 'EventRecurBy')
+#         app_label = 'cal'
+#         verbose_name = _("Event recursion by")
+#         verbose_name_plural = _("Event recursions by")
+#
+#     event = dd.ForeignKey('cal.RecurrentEvent', related_name='recur_by_rules')
+#     recurby = dd.ForeignKey('cal.RecurByRule')
 
 
 class RecurrenceSet(Started, Ended):
@@ -551,6 +581,7 @@ class RecurrenceSet(Started, Ended):
         _("Recurrency"), blank=True)  # default='monthly'
     every = models.IntegerField(_("Repeat every"), default=1)
     positions = models.CharField(_("Positions"), blank=True, max_length=50)
+    # positioning_type = PositioningTypes.field(blank=True, null=True)
 
     monday = models.BooleanField(Weekdays.monday.text, default=False)
     tuesday = models.BooleanField(Weekdays.tuesday.text, default=False)
@@ -564,6 +595,16 @@ class RecurrenceSet(Started, Ended):
         _("Number of events"),
         blank=True, null=True)
 
+    def build_rrule(self) -> str:
+        rule = f"FREQ={self.every_unit.name.upper()};INTERVAL={self.every}"
+        if self.end_date:
+            rule += f";UNTIL={self.get_datetime('end').isoformat()}"
+        elif self.max_events:
+            rule += f";COUNT={self.max_events}"
+        # for r in self.recur_by_rules.all():
+        #     rule += f";{r.recurby.name.name.upper()}={r.positions}"
+        return rule
+
     @classmethod
     def on_analyze(cls, site):
         cls.WEEKDAY_FIELDS = dd.fields_list(
