@@ -129,6 +129,12 @@ class Room(mixins.BabelNamed, ContactRelated, Colored):
         verbose_name_plural = _("Rooms")
 
     description = dd.RichTextField(_("Description"), blank=True)
+    calendar = dd.ForeignKey(
+        'cal.Calendar',
+        help_text=_("Calendar where events in this room are published."),
+        related_name='room_calendars',
+        blank=True, null=True)
+
 
 dd.update_field(
     Room, 'company', verbose_name=_("Responsible"))
@@ -232,6 +238,7 @@ class Calendar(mixins.BabelNamed, GoogleCalendarSynchronized):
     )
     # choices=COLOR_CHOICES)
 
+
 class BaseSubscription(UserAuthored):
     allow_cascaded_delete = ['user', 'calendar']
     class Meta:
@@ -310,8 +317,6 @@ class Task(Component):
     #     super(Comment, cls).setup_parameters(fields)
 
 
-
-
 class EventPolicy(mixins.BabelNamed, RecurrenceSet):
     class Meta:
         app_label = 'cal'
@@ -424,9 +429,6 @@ class Event(
 
     memo_command = 'cal_entry'
 
-    publisher_location = "cal"
-    publisher_page_template = "cal/event.pub.html"
-
     update_guests = UpdateGuests()
     update_events = UpdateEntriesByEvent()
     show_today = ShowEntriesByDay('start_date')
@@ -927,11 +929,16 @@ class Event(
         return False
     # reminder.return_type = dd.DisplayField(_("Reminder"))
 
+    # def get_calendar(self):
+    #     # for sub in Subscription.objects.filter(user=ar.get_user()):
+    #         # if sub.contains_event(self):
+    #             # return sub
+    #     return None
+
     def get_calendar(self):
-        # for sub in Subscription.objects.filter(user=ar.get_user()):
-            # if sub.contains_event(self):
-                # return sub
-        return None
+        if self.room is not None and self.room.calendar is not None:
+            return self.room.calendar
+        return settings.SITE.site_config.site_calendar
 
     @dd.virtualfield(dd.ForeignKey('cal.Calendar'))
     def calendar(self, ar):
