@@ -154,35 +154,6 @@ class Plannable(dd.Model):
         return [e.obj2href(ar, ar.actor.get_calview_div(e, ar))
             for e in entries]
 
-    @classmethod
-    def unused_gen_insert_button(cls, actor, header_items, ar, target_day):
-        """Hackish solution to not having to recreate a new sub request when generating lots of insert buttons.
-        Stores values in the actor as a cache, and uses id(ar) to check if it's a new request and needs updating.
-        Works by replacing known unique value with the correct known value for the insert window."""
-        # print(20200227, cls)
-        insert_action = rt.models.cal.Events.insert_action
-        # if ar.get_user().authenticated:
-        if insert_action.get_view_permission(ar.get_user().user_type):
-
-            if (getattr(actor, "insert_button", None) is not None
-                    and actor.insert_button_ar_id == id(ar)):
-                insert_button = actor.insert_button.__copy__()
-            else:
-                # print("Making button")
-                sar = insert_action.request_from(ar)
-            # print(20170217, sar)
-                sar.known_values = dict(start_date="PLACEHOLDER")
-                actor.insert_button = sar.ar2button(style="float: right;")
-                actor.insert_button_ar_id = id(ar)
-                insert_button = actor.insert_button.__copy__()
-
-            insert_button.set("href", insert_button.get("href").replace("PLACEHOLDER", str(target_day)))
-            # insert_button = E.span(insert_button , style="float: right;")
-            header_items.append(insert_button)
-            # btn.set("style", "padding-left:10px")
-        return header_items
-
-
 
 class HeaderRow(TableRow):
 
