@@ -51,7 +51,7 @@ class ClientContact(ClientContactBase):
         if not self.remark and not self.type \
            and not self.company and not self.contact_person:
             raise ValidationError(_("Must fill at least one field."))
-        super(ClientContact, self).full_clean(*args, **kw)
+        super().full_clean(*args, **kw)
 
 
 dd.update_field(ClientContact, 'contact_person',
