@@ -1,18 +1,17 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2021 Rumma & Ko Ltd
+# Copyright 2008-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import os
+import datetime
 from email.utils import parseaddr
 
-from etgen.html import E, join_elems, forcetext
+from etgen.html import E, join_elems, forcetext, tostring
 from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.db import models
 from django.db.models import Q
 
-from etgen.html import tostring
-
 from lino import mixins
 from lino.api import dd, rt, _
 from lino.mixins.duplicable import Duplicable
@@ -31,9 +30,10 @@ from lino_xl.lib.phones.mixins import ContactDetailsOwner
 from lino_xl.lib.skills.mixins import Feasible
 from lino_xl.lib.vat.choicelists import VatSubjectable
 
+from .mixins import ContactRelated
 from .choicelists import CivilStates
-from .roles import SimpleContactsUser, ContactsStaff
 from .choicelists import PartnerEvents
+from .roles import SimpleContactsUser, ContactsStaff
 
 if dd.plugins.contacts.use_vcard_export:
     from lino.modlib.uploads.mixins import UploadBase
@@ -243,11 +243,8 @@ class Partner(Duplicable, ContactDetailsOwner, mixins.Polymorphic,
         export_vcf = ExportVCardFile()
         import_text = ImportText()
 
-    prefix = models.CharField(
-        _("Name prefix"), max_length=200, blank=True)
-
-    name = models.CharField(max_length=200, verbose_name=_('Name'))
-
+    prefix = models.CharField(_("Name prefix"), max_length=200, blank=True)
+    name = models.CharField(_('Name'), max_length=200)
     remarks = models.TextField(_("Remarks"), blank=True)  # ,null=True)
 
     quick_search_fields = "prefix name phone gsm"
@@ -315,7 +312,7 @@ class Partner(Duplicable, ContactDetailsOwner, mixins.Polymorphic,
             # buttons = join_elems(buttons, ', ')
             elems.append(E.p(str(_("See as ")), *buttons,
                              style="font-size:8px;text-align:right;padding:3pt;"))
-        elems += self.get_name_elems(ar)
+        elems += self.get_name_elems(ar, sep=E.br)
         elems.append(E.br())
         elems += join_elems(list(self.address_location_lines()), sep=E.br)
         elems = [
@@ -326,9 +323,24 @@ class Partner(Duplicable, ContactDetailsOwner, mixins.Polymorphic,
         elems += ContactDetailsOwner.get_overview_elems(self, ar)
         return elems
 
+    # def as_copyright_owner(self, ar=None):
+    #     html = _("Copyright (c) {}".format(datetime.date.today().year))
+    #     html += "".join([tostring(e) for e in self.get_name_elems(ar)])
+    #     html += ", "
+    #     html += ", ".join([tostring(e) for e in self.address_location_lines()])
+    #     if self.email:
+    #         html += """, <a href="{0}">{0}</a>""".format(self.email)
+    #     elif self.url:
+    #         html += """, <a href="{0}">{0}</a>""".format(self.url)
+    #     html += "."
+    #     # elems += AddressOwner.get_overview_elems(self, ar)
+    #     # elems += ContactDetailsOwner.get_overview_elems(self, ar)
+    #     # return "".join([tostring(e) for e in elems])
+    #     yield html
+
     def as_paragraph(self, ar):
         elems = []
-        elems += self.get_name_elems(ar)
+        elems += self.get_name_elems(ar, sep=" ")
         elems.append(E.br())
         elems += join_elems(list(self.address_location_lines()), sep=E.br)
         # elems += AddressOwner.get_overview_elems(self, ar)
@@ -337,7 +349,7 @@ class Partner(Duplicable, ContactDetailsOwner, mixins.Polymorphic,
         # return tostring(E.div(*elems))
 
 
-    def get_name_elems(self, ar):
+    def get_name_elems(self, ar, sep=E.br):
         elems = []
         if self.prefix:
             elems += [self.prefix, ' ']
@@ -533,9 +545,9 @@ class Person(Human, Born, Partner):
         #     kw.update(salutation=False)
         yield self.get_full_name(*args, **kw)
 
-    def get_name_elems(self, ar):
+    def get_name_elems(self, ar, sep=E.br):
         elems = [self.get_salutation(nominative=True), ' ',
-                 self.prefix, E.br()]
+                 self.prefix, sep]
         elems += [self.first_name, ' ', E.b(self.last_name)]
         return elems
 
@@ -801,7 +813,6 @@ dd.inject_field(
         help_text=_("The next automatic id for any new partner.")))
 
 
-
 @dd.receiver(dd.pre_analyze)
 def company_model_alias(sender, **kw):
     """
