@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2020 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import logging ; logger = logging.getLogger(__name__)
@@ -80,9 +80,8 @@ class Place(Hierarchical, mixins.BabelNamed):
         verbose_name_plural = _("Places")
         abstract = dd.is_abstract_model(__name__, 'Place')
 
-        if not settings.SITE.allow_duplicate_cities:
-            unique_together = (
-                'country', 'parent', 'name', 'type', 'zip_code')
+        if not dd.get_plugin_setting('countries', 'allow_duplicate_cities'):
+            unique_together = ('country', 'parent', 'name', 'type', 'zip_code')
 
     country = dd.ForeignKey('countries.Country')
     zip_code = models.CharField(max_length=8, blank=True)
