@@ -16,8 +16,7 @@ from lino.modlib.notify.mixins import ChangeNotifier
 from lino.core.roles import SiteAdmin, SiteUser  # , UserRole
 from lino.core import constants
 
-class Group(mixins.BabelNamed, mixins.Referrable, ChangeNotifier,
-            Commentable):
+class Group(mixins.BabelNamed, mixins.Referrable, ChangeNotifier, Commentable):
 
     class Meta:
         app_label = 'groups'
@@ -25,6 +24,8 @@ class Group(mixins.BabelNamed, mixins.Referrable, ChangeNotifier,
         verbose_name = _("Group")
         verbose_name_plural = _("Groups")
 
+    memo_command = "group"
+
     description = dd.RichTextField(
         _("Description"), blank=True, format='plain')
 
