@@ -27,17 +27,17 @@ class Plugin(ad.Plugin):
     """The age (in years) a person needs to have in order to be considered
     adult."""
     # adult_age = datetime.timedelta(days=18*365)
-    
+
     def on_site_startup(self, site):
         self.person_model = site.models.resolve(self.person_model)
         super(Plugin, self).on_site_startup(site)
-        
-    def post_site_startup(self, site):
-        if not site.is_installed('memo'):
-            return
 
-        rdm = site.plugins.memo.parser.register_django_model
-        rdm('household', site.models.households.Household)
+    # def post_site_startup(self, site):
+    #     if not site.is_installed('memo'):
+    #         return
+    #
+    #     rdm = site.plugins.memo.parser.register_django_model
+    #     rdm('household', site.models.households.Household)
     
     def setup_main_menu(config, site, user_type, m):
         mnugrp = site.plugins.contacts
