@@ -552,6 +552,8 @@ class PlansByArea(Plans):
 
     @classmethod
     def get_master_instance(self, ar, model, pk):
+        if not pk:
+            return None
         return InvoicingAreas.get_by_value(pk)
 
 
