@@ -11,10 +11,11 @@ from etgen.html import E
 from lino.utils import SumCollector
 from lino.mixins import Sequenced
 from lino.api import dd, rt, _
+from lino.core import constants
+from lino_xl.lib.contacts.mixins import PartnerRelated
 
 from .choicelists import VoucherTypes, TradeTypes, VoucherStates
 from .roles import LedgerUser
-from lino.core import constants
 
 project_model = dd.get_plugin_setting('ledger', 'project_model', None)
 has_payment_methods = dd.get_plugin_setting('ledger', 'has_payment_methods', False)
@@ -31,20 +32,16 @@ class ProjectRelated(dd.Model):
 
     @classmethod
     def get_registrable_fields(cls, site):
-        for f in super(ProjectRelated, cls).get_registrable_fields(site):
+        for f in super().get_registrable_fields(site):
             yield f
         if project_model:
             yield 'project'
 
 
-class PartnerRelated(dd.Model):
+class PaymentRelated(PartnerRelated):
     class Meta:
         abstract = True
 
-    partner = dd.ForeignKey(
-        'contacts.Partner',
-        related_name="%(app_label)s_%(class)s_set_by_partner",
-        blank=True, null=True)
     payment_term = dd.ForeignKey(
         'ledger.PaymentTerm',
         related_name="%(app_label)s_%(class)s_set_by_payment_term",
@@ -54,38 +51,21 @@ class PartnerRelated(dd.Model):
         payment_method = dd.ForeignKey(
             'ledger.PaymentMethod',
             blank=True, null=True)
+    else:
+        payment_method = dd.DummyField(())
 
     def get_payment_term(self):
         return self.payment_term
 
-    def get_partner(self):
-        """Overrides Voucher.get_partner"""
-        return self.partner
-
-    def get_print_language(self):
-        p = self.get_partner()
-        if p is not None:
-            return p.language
-
-    def get_recipient(self):
-        return self.partner
-    recipient = property(get_recipient)
-
-    def partner_changed(self, ar=None):
-        # does nothing but we need it so that subclasses like
-        # BankAccount can call super().partner_changed()
-        pass
-
     @classmethod
     def get_registrable_fields(cls, site):
-        for f in super(PartnerRelated, cls).get_registrable_fields(site):
+        for f in super().get_registrable_fields(site):
             yield f
-        yield 'partner'
         yield 'payment_term'
 
     def full_clean(self, *args, **kw):
         self.fill_defaults()
-        super(PartnerRelated, self).full_clean(*args, **kw)
+        super().full_clean(*args, **kw)
 
     def fill_defaults(self):
         if not self.payment_term and self.partner_id:
@@ -102,11 +82,6 @@ class PartnerRelated(dd.Model):
         if self.payment_term:
             self.due_date = self.payment_term.get_due_date(self.entry_date)
 
-    # TODO: #4305 (An alternative to the FOO_changed method)
-    # def entry_date_changed(self, ar=None):
-    #     super(PartnerRelated, self).entry_date_changed(ar)
-    #     if self.payment_term:
-    #         self.due_date = self.payment_term.get_due_date(self.entry_date)
 
 class CashPayable(dd.Model):
 
@@ -140,7 +115,7 @@ class Payable(dd.Model):
 
     @classmethod
     def get_registrable_fields(cls, site):
-        for f in super(Payable, cls).get_registrable_fields(site):
+        for f in super().get_registrable_fields(site):
             yield f
         yield 'your_ref'
 
@@ -151,7 +126,7 @@ class Payable(dd.Model):
         raise NotImplemented()
 
     def get_movement_description(self, mvt, ar=None):
-        for chunk in super(Payable, self).get_movement_description(mvt, ar):
+        for chunk in super().get_movement_description(mvt, ar):
             yield chunk
         if self.your_ref:
             yield self.your_ref
@@ -263,10 +238,12 @@ class VoucherItem(dd.Model):
         """Items of registered invoices may not be edited
 
         """
+        if not self.voucher_id:
+            return False
         if not self.voucher.state.is_editable:
             if not ba.action.readonly:
                 return False
-        return super(VoucherItem, self).get_row_permission(ar, state, ba)
+        return super().get_row_permission(ar, state, ba)
 
     def get_ana_account(self):
         return None
@@ -279,6 +256,10 @@ class SequencedVoucherItem(Sequenced):
     def get_siblings(self):
         return self.voucher.items.all()
 
+    def __str__(self):
+        return str(self.voucher) + "#" + str(self.seqno)
+        # return super().__str__()
+
 
 class AccountVoucherItem(VoucherItem, SequencedVoucherItem):
 
@@ -370,19 +351,19 @@ class PeriodRangeObservable(dd.Model):
                     "Optional end of observed period range. "
                     "Leave empty to observe only the start period."),
                 verbose_name=_("Period until")))
-        super(PeriodRangeObservable, cls).setup_parameters(fields)
+        super().setup_parameters(fields)
 
     @classmethod
     def get_request_queryset(cls, ar, **kwargs):
         pv = ar.param_values
-        qs = super(PeriodRangeObservable, cls).get_request_queryset(ar, **kwargs)
+        qs = super().get_request_queryset(ar, **kwargs)
         flt = rt.models.ledger.AccountingPeriod.get_period_filter(
             cls.observable_period_prefix, pv.start_period, pv.end_period)
         return qs.filter(**flt)
 
     @classmethod
     def get_title_tags(cls, ar):
-        for t in super(PeriodRangeObservable, cls).get_title_tags(ar):
+        for t in super().get_title_tags(ar):
             yield t
         pv = ar.param_values
         if pv.start_period is not None:
