@@ -27,13 +27,13 @@ class Plugin(ad.Plugin):
     needs_plugins = ['lino.modlib.memo']
     menu_group = 'office'
 
-    def post_site_startup(self, site):
-        super(Plugin, self).post_site_startup(site)
-
-        if site.is_installed('memo'):
-            site.plugins.memo.parser.register_django_model(
-                'note', site.models.notes.Note,
-                title=lambda obj: obj.subject)
+    # def post_site_startup(self, site):
+    #     super(Plugin, self).post_site_startup(site)
+    #
+    #     if site.is_installed('memo'):
+    #         site.plugins.memo.parser.register_django_model(
+    #             'note', site.models.notes.Note,
+    #             title=lambda obj: obj.subject)
     
     def setup_main_menu(self, site, user_type, m):
         mg = self.get_menu_group()
@@ -51,4 +51,3 @@ class Plugin(ad.Plugin):
         # mg = site.plugins.office
         m = m.add_menu(mg.app_label, mg.verbose_name)
         m.add_action('notes.AllNotes')
-
