@@ -1,14 +1,15 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2021 Rumma & Ko Ltd
+# Copyright 2012-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
+from django.utils import translation
 from lino.api import rt, _
 from lino.utils import Cycler
 from lino.modlib.comments.fixtures.demo2 import lorem, short_lorem
 
-welcome = """Welcome to our great website.  We are proud to present
+welcome = _("""Welcome to our great website. We are proud to present
 the best content about foo, bar and baz.
-"""
+""")
 
 BODIES = Cycler([lorem, short_lorem])
 
@@ -39,13 +40,14 @@ def objects():
             continue
         kwargs = dict(language=language)
         count = 0
-        for ref, title, body in pages:
-            kwargs.update(ref=ref)
-            if body is None:
-                body = BODIES.pop()
-                for i in range(count):
-                    body += BODIES.pop()
-            p = Node(title=title, body=body, **kwargs)
-            if ref == "index":
-                kwargs.update(parent=p)
-            yield p
+        with translation.override(language):
+            for ref, title, body in pages:
+                kwargs.update(ref=ref)
+                if body is None:
+                    body = BODIES.pop()
+                    for i in range(count):
+                        body += BODIES.pop()
+                p = Node(title=title, body=str(body), **kwargs)
+                if ref == "index":
+                    kwargs.update(parent=p)
+                yield p
