@@ -66,12 +66,12 @@ class Page(Hierarchical, Sequenced, Previewable, Publishable):
     # body = dd.BabelTextField(_("Body"), blank=True, format='plain')
     # raw_html = models.BooleanField(_("raw html"), default=False)
 
-    def as_page(self, ar, display_mode="list"):
+    def as_page(self, ar, display_mode="list", hlevel=1):
         if display_mode == "detail":
-            yield "<h1>{}</h1>".format(self.title)
+            yield "<h{0}>{1}</h{0}>".format(hlevel, self.title)
             yield self.body_full_preview
             for obj in self.children.order_by('seqno'):
-                for i in obj.as_page(ar, "list"):
+                for i in obj.as_page(ar, "list", hlevel=hlevel+1):
                     yield i
         else:
             # the whole list item is clickable
@@ -80,10 +80,10 @@ class Page(Hierarchical, Sequenced, Previewable, Publishable):
                 yield """<a href="{}"
                 style="text-decoration:none; color: black;">
                 """.format(escape(url))
-            yield "<h2>{}</h2>".format(self.title)
+            yield "<h{0}>{1}</h{0}>".format(hlevel, self.title)
             yield self.body_short_preview
             for obj in self.children.order_by('seqno'):
-                for i in obj.as_page(ar, "list"):
+                for i in obj.as_page(ar, "list", hlevel+1):
                     yield i
             yield """</a>"""
 
@@ -194,7 +194,8 @@ class PageDetail(dd.DetailLayout):
     main = """
     ref language parent seqno
     title child_node_depth
-    body:70 pages.PagesByParent:30
+    body:70
+    pages.PagesByParent:30
     """
 
 
@@ -223,6 +224,7 @@ class PagesByParent(Pages):
     #~ column_names = "title user *"
     order_by = ["seqno"]
     column_names = "seqno title *"
+    display_mode = ((None, constants.DISPLAY_MODE_LIST),)
 
 #~ if settings.SITE.project_model:
     #~ class PagesByProject(Pages):
