@@ -125,7 +125,7 @@ class ContactDetailsByPartner(ContactDetails):
 
     @classmethod
     def get_table_summary(self, obj, ar):
-        sar = self.request_from(ar, master_instance=obj)
+        sar = self.request(parent=ar, master_instance=obj)
         items = [o.detail_type.as_html(o, sar)
                  for o in sar if not o.end_date]
 
