@@ -13,6 +13,7 @@ from lino_xl.lib.ledger.mixins import Matching, SequencedVoucherItem, CashPayabl
 from lino_xl.lib.ledger.models import Voucher
 from lino_xl.lib.ledger.choicelists import TradeTypes
 from lino_xl.lib.invoicing.mixins import InvoiceGenerator
+from lino_xl.lib.invoicing.mixins import InvoicingTargetVoucher, InvoicingTargetItem
 from .mixins import SalesDocument, ProductDocItem
 
 has_payment_methods = dd.get_plugin_setting('ledger', 'has_payment_methods', False)
@@ -42,7 +43,7 @@ class PaperType(BabelNamed):
         return rt.find_template_config_files(
             bm.template_ext, cls.templates_group)
 
-class VatProductInvoice(SalesDocument, Matching):
+class VatProductInvoice(SalesDocument, Matching, InvoicingTargetVoucher):
     # edit_totals = True
     quick_search_fields = "partner__name subject"
 
@@ -63,10 +64,9 @@ class VatProductInvoice(SalesDocument, Matching):
 
     @classmethod
     def get_registrable_fields(cls, site):
-        for f in super(VatProductInvoice, cls).get_registrable_fields(site):
+        for f in super().get_registrable_fields(site):
             yield f
         yield 'due_date'
-        # yield 'order'
         yield 'voucher_date'
         yield 'entry_date'
         yield 'user'
@@ -100,7 +100,7 @@ if has_payment_methods:
 
     class StartNewSale(dd.Action):
         label = _("Start new sale")
-        show_in_bbar = False
+        show_in_toolbar = False
 
         def get_action_permission(self, ar, obj, state):
             if ar.get_user().sales_journal is None:
@@ -185,7 +185,8 @@ else:
     dd.inject_field('users.User', 'sales_journal', dd.DummyField())
 
 
-class InvoiceItem(ProductDocItem, SequencedVoucherItem, InvoiceGenerator):
+class InvoiceItem(ProductDocItem, SequencedVoucherItem, InvoiceGenerator,
+        InvoicingTargetItem):
     class Meta:
         app_label = 'sales'
         abstract = dd.is_abstract_model(__name__, 'InvoiceItem')
@@ -210,17 +211,26 @@ class InvoiceItem(ProductDocItem, SequencedVoucherItem, InvoiceGenerator):
 
     @classmethod
     def get_generators_for_plan(cls, plan, partner=None):
-        jnls = [o.source_journal
-            for o in rt.models.invoicing.FollowUpRule.objects.filter(
-                target_journal=plan.area.journal)]
-        if len(jnls):
-            qs = cls.objects.filter(voucher__journal__in=jnls)
-            if partner is not None:
-                qs = qs.filter(voucher__partner=partner)
-            return qs
-        return []
+        jnls = set(plan.invoicing_area.get_source_journals())
+        if len(jnls) == 0:
+            return []
+
+        # jnls = [o.source_journal
+        #     for o in rt.models.invoicing.FollowUpRule.objects.filter(
+        #         source_journal=plan.invoicing_area.source_journal)]
+        # jnls = [o.source_journal
+        #     for o in rt.models.invoicing.FollowUpRule.objects.filter(
+        #         invoicing_area=plan.invoicing_area)]
+        # qs = cls.objects.filter(voucher__journal__in=plan.invoicing_area.get_source_journals())
+        qs = cls.objects.filter(voucher__journal__in=jnls)
+        if partner is not None:
+            # qs = qs.filter(voucher__partner=partner)
+            fldname = cls.get_partner_filter_field(partner)
+            qs = cls.filter_by_invoice_recipient(qs, partner, fldname)
+        return qs
+
         # trs = rt.models.invoicing.FollowUpRule.objects.filter(
-        #     target_journal=plan.area.journal)
+        #     source_journal=plan.area.journal)
         # if trs.exist():
         # jnls = []
         # for tr in trs:
@@ -260,13 +270,13 @@ class InvoiceItem(ProductDocItem, SequencedVoucherItem, InvoiceGenerator):
     def get_invoiceable_paper_type(self):
         return None
 
-    def setup_invoice_from_suggestion(self, invoice, plan, info):
-        if info.invoicing_max_date is not None:
-            invoice.invoicing_min_date = info.invoicing_min_date
-            invoice.invoicing_max_date = info.invoicing_max_date
-        else:
-            invoice.invoicing_min_date = plan.min_date
-            invoice.invoicing_max_date = plan.get_max_date()
+    # def setup_invoice_from_suggestion(self, invoice, plan, info):
+    #     if info.invoicing_max_date is not None:
+    #         invoice.invoicing_min_date = info.invoicing_min_date
+    #         invoice.invoicing_max_date = info.invoicing_max_date
+    #     else:
+    #         invoice.invoicing_min_date = plan.min_date
+    #         invoice.invoicing_max_date = plan.get_max_date()
 
     def setup_invoice_item(self, item):
         pass
