@@ -91,7 +91,7 @@ def objects():
             country="BE",
             zip_code="1000",
             # city="Bruxelles",
-            vat_id='BE 0476 306 127',
+            # vat_id='BE 0476 306 127',
             street="Boulevard Simón Bolívar",
             street_no=34)
     # 1000 Bruxelles
