@@ -77,6 +77,8 @@ class InvoicesBySubscription(InvoicesByPartner):
         # the master instance of InvoicesByPartner must be a Partner, but since
         # we use this on an order, we get the pk of an order
 
+        if not pk:
+            return None
         assert model is rt.models.contacts.Partner
         mi = rt.models.subscriptions.Subscription.objects.get(pk=pk)
         return mi.get_invoiceable_partner()
