@@ -49,7 +49,7 @@ dd.inject_field(
     dd.ForeignKey('teams.Team', blank=True, null=True))
 
 
-from lino.modlib.users.desktop import Users
+from lino.modlib.users.ui import Users
 
 class UsersByTeam(Users):
     master_key = 'team'
