@@ -396,7 +396,7 @@ class Tickets(dd.Table):
 
     @classmethod
     def get_simple_parameters(cls):
-        for p in super(Tickets, cls).get_simple_parameters():
+        for p in super().get_simple_parameters():
             yield p
         yield 'end_user'
         yield 'state'
@@ -410,14 +410,14 @@ class Tickets(dd.Table):
 
     @classmethod
     def get_queryset(self, ar, **filter):
-        qs = super(Tickets, self).get_queryset(ar, **filter)
+        qs = super().get_queryset(ar, **filter)
         return qs.select_related(
             'user', 'assigned_to',  # 'project',
             'duplicate_of', 'end_user')
 
     @classmethod
     def get_request_queryset(self, ar):
-        qs = super(Tickets, self).get_request_queryset(ar)
+        qs = super().get_request_queryset(ar)
         pv = ar.param_values
 
         if pv.observed_event:
@@ -519,7 +519,7 @@ class Tickets(dd.Table):
 
     @classmethod
     def get_title_tags(self, ar):
-        for t in super(Tickets, self).get_title_tags(ar):
+        for t in super().get_title_tags(ar):
             yield t
         pv = ar.param_values
         if pv.start_date or pv.end_date:
@@ -537,7 +537,7 @@ class DuplicatesByTicket(Tickets):
     display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     label = _("Duplicates")
     master_key = 'duplicate_of'
-    column_names = "overview state *"
+    column_names = "detail_link state *"
     editable = False
     required_roles = set([])
 
@@ -552,7 +552,7 @@ class RefTickets(Tickets):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(RefTickets, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(
             has_ref=dd.YesNo.yes
         )
@@ -570,7 +570,7 @@ class UnassignedTickets(Tickets):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(UnassignedTickets, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(show_assigned=dd.YesNo.no)
         # kw.update(show_private=dd.YesNo.no)
         # kw.update(show_active=dd.YesNo.yes)
@@ -581,7 +581,7 @@ class UnassignedTickets(Tickets):
 
 class TicketsByEndUser(Tickets):
     master_key = 'end_user'
-    column_names = ("overview:50 workflow_buttons * ")
+    column_names = ("detail_link:50 workflow_buttons * ")
     # display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     required_roles = dd.login_required(TicketsReader)
 
@@ -610,21 +610,16 @@ class TicketsByType(Tickets):
     column_names = "summary state  *"
 
 
-# class TicketsByTopic(Tickets):
-#     master_key = 'topic'
-#     column_names = "summary state  *"
-
-
 class PublicTickets(Tickets):
     label = _("Public tickets")
     order_by = ["-id"]
-    column_names = 'overview:50 ticket_type:10 site:10 *'
+    column_names = 'detail_link:50 ticket_type:10 site:10 *'
 
     # filter = Q(assigned_to=None)
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(PublicTickets, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         # kw.update(show_assigned=dd.YesNo.no)
         kw.update(show_private=dd.YesNo.no)
         # kw.update(show_active=dd.YesNo.yes)
@@ -644,7 +639,7 @@ class TicketsToTriage(Tickets):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(TicketsToTriage, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(state=TicketStates.new)
         return kw
 
@@ -656,24 +651,24 @@ class TicketsToTalk(Tickets):
     required_roles = dd.login_required(Triager)
     order_by = ["-priority", "-deadline", "-id"]
     # order_by = ["-id"]
-    column_names = "overview:50 priority #deadline waiting_for " \
+    column_names = "summary:50 priority #deadline waiting_for " \
                    "workflow_buttons:40 *"
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(TicketsToTalk, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(state=TicketStates.talk)
         return kw
 
 
 class TicketsNeedingMyFeedback(TicketsToTalk):
     label = _("Tickets needing my feedback")
-    column_names = "overview:50 priority #deadline last_commenter " \
+    column_names = "summary:50 priority #deadline last_commenter " \
                    "workflow_buttons:40 *"
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(TicketsNeedingMyFeedback, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(not_last_commenter=ar.get_user(),
                   subscriber=ar.get_user())
         return kw
@@ -681,12 +676,12 @@ class TicketsNeedingMyFeedback(TicketsToTalk):
 
 class MyTicketsNeedingFeedback(TicketsNeedingMyFeedback):
     label = _("My tickets needing feedback")
-    column_names = "overview:50 priority #deadline " \
+    column_names = "detail_link:50 priority #deadline " \
                    "workflow_buttons:40 *"
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyTicketsNeedingFeedback, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(last_commenter=ar.get_user(),
                   not_last_commenter=None)
         return kw
@@ -697,12 +692,12 @@ class ActiveTickets(Tickets):
     required_roles = dd.login_required(Triager)
     order_by = ["-id"]
     # order_by = ["-modified", "id"]
-    column_names = 'overview:50 priority site ' \
+    column_names = 'detail_link:50 priority site ' \
                    'assigned_to:10 ticket_type:10 workflow_buttons:40 *'
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(ActiveTickets, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(show_active=dd.YesNo.yes)
         # kw.update(show_closed=dd.YesNo.no)
         # kw.update(show_standby=dd.YesNo.no)
@@ -713,7 +708,7 @@ class MyTickets(My, Tickets):
     # label = _("My tickets")
     required_roles = dd.login_required(Reporter)
     order_by = ["priority", "-id"]
-    column_names = "priority detail_link assigned_to planned_time SUMMARY_FIELDS workflow_buttons *"
+    column_names = "priority detail_link assigned_to planned_time workflow_buttons *"
     params_panel_hidden = True
     # params_layout = """
     # user end_user site #project state #priority
@@ -732,55 +727,13 @@ class MyTickets(My, Tickets):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyTickets, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(show_active=dd.YesNo.yes)
         # kw.update(show_closed=dd.YesNo.no)
         # kw.update(show_standby=dd.YesNo.no)
         return kw
 
 
-# class TicketsSummary(Tickets):
-#     # order_by = ["state", "priority", "-id"]
-#     order_by = ["priority", "-id"]
-#     display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
-#
-#     @classmethod
-#     def get_table_summary(self, master, ar):
-#         # master is None when called on a master table.
-#         if master is None:
-#             sar = ar
-#         else:
-#             sar = self.request_from(ar, master_instance=master)
-#
-#         # every element of `items` is a tuple `(state,
-#         # list-of-objects)`.  in ar they are ordered by state. we just
-#         # group them
-#         items = []
-#         items_by_state = dict()
-#         # ci = None
-#
-#         for obj in sar:  # self.get_request_queryset(ar):
-#             btn = obj.obj2href(ar)
-#             if obj.state in items_by_state:
-#                 lst = items_by_state[obj.state]
-#             else:
-#                 lst = []
-#                 items_by_state[obj.state] = lst
-#                 items.append((obj.state, lst))
-#             lst.append(btn)
-#
-#             # if ci is not None and ci[0] is obj.state:
-#             #     ci[1].append(btn)
-#             # else:
-#             #     ci = (obj.state, [btn])
-#             #     items.append(ci)
-#
-#         # now render them as a UL containing on LI per item
-#         items = [E.li(str(i[0]), ' : ', *join_elems(i[1], ", "))
-#                  for i in items]
-#
-#         return E.ul(*items)
-
 class MyTicketsToWork(Tickets):
     label = _("Tickets to work")
     order_by = ["-priority", "-modified"]
@@ -793,13 +746,48 @@ class MyTicketsToWork(Tickets):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyTicketsToWork, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(show_active=dd.YesNo.yes)
         # kw.update(show_todo=dd.YesNo.yes)
         kw.update(assigned_to=ar.get_user())
         return kw
 
 
+class TicketsBySite(Tickets):
+    required_roles = dd.login_required(Reporter)
+    # label = _("Known problems")
+    master_key = 'site'
+    column_names = "priority detail_link:50 ticket_type workflow_buttons *"
+    order_by = ["-priority", "-id"]
+
+    @classmethod
+    def param_defaults(self, ar, **kw):
+        # mi = ar.master_instance
+        kw = super().param_defaults(ar, **kw)
+        kw.update(show_active=dd.YesNo.yes)
+        # kw.update(interesting_for=mi.partner)
+        # kw.update(end_date=dd.today())
+        # kw.update(observed_event=TicketEvents.todo)
+        return kw
+
+
+class TicketsByOrder(Tickets):
+    required_roles = dd.login_required(Reporter)
+    master_key = 'order'
+    column_names = "priority detail_link:50 ticket_type workflow_buttons *"
+    order_by = ["-priority", "-id"]
+
+    @classmethod
+    def param_defaults(self, ar, **kw):
+        # mi = ar.master_instance
+        kw = super().param_defaults(ar, **kw)
+        kw.update(show_active=dd.YesNo.yes)
+        # kw.update(interesting_for=mi.partner)
+        # kw.update(end_date=dd.today())
+        # kw.update(observed_event=TicketEvents.todo)
+        return kw
+
+
 class SiteDetail(dd.DetailLayout):
     bottom_left = """
     description
@@ -924,23 +912,6 @@ class SitesByPerson(Sites):
     column_names = "ref name *"
 
 
-class TicketsBySite(Tickets):
-    required_roles = dd.login_required(Reporter)
-    # label = _("Known problems")
-    master_key = 'site'
-    column_names = "priority overview:50 ticket_type workflow_buttons *"
-    order_by = ["-priority", "-id"]
-
-    @classmethod
-    def param_defaults(self, ar, **kw):
-        # mi = ar.master_instance
-        kw = super(TicketsBySite, self).param_defaults(ar, **kw)
-        kw.update(show_active=dd.YesNo.yes)
-        # kw.update(interesting_for=mi.partner)
-        # kw.update(end_date=dd.today())
-        # kw.update(observed_event=TicketEvents.todo)
-        return kw
-
 
 class CheckListItems(dd.Table):
     model = "tickets.CheckListItem"
