@@ -114,7 +114,7 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
     def as_paragraph(self, ar):
         txt = ar.add_detail_link(self, str(self))
         if not ar.is_obvious_field('ticket'):
-            txt += _(" working on ") + ar.obj2str(self.get_ticket())
+            txt += _(" working on ") + ar.obj2htmls(self.get_ticket())
         return txt
 
     def get_ticket(self):
